@@ -5,6 +5,7 @@ import os
 import platform
 import itertools
 import distutils.errors
+
 from setuptools.extern.six.moves import filterfalse
 
 if platform.system() == 'Windows':
@@ -769,6 +770,7 @@ class EnvironmentInfo:
     """
     # Variables and properties in this class use originals CamelCase variables
     # names from Microsoft source files for more easy comparaison.
+
     def __init__(self, arch, vc_ver=None, vc_min_ver=None):
         self.pi = PlatformInfo(arch)
         self.ri = RegistryInfo(self.pi)
@@ -907,7 +909,7 @@ class EnvironmentInfo:
                 os.path.join(self.si.WindowsSdkDir, 'UnionMetadata'),
                 os.path.join(
                     ref,
-                    'Windows.Foundation.UniversalApiContract'
+                    'Windows.Foundation.UniversalApiContract',
                     '1.0.0.0',
                 ),
                 os.path.join(
@@ -917,7 +919,7 @@ class EnvironmentInfo:
                 ),
                 os.path.join(
                     ref,
-                    'Windows.Networking.Connectivity.WwanContract'
+                    'Windows.Networking.Connectivity.WwanContract',
                     '1.0.0.0',
                 ),
                 os.path.join(
